Examples
========

Let us triangulate a simple square

.. plot:: plot/ex1.py
    :include-source:

In order to set maximum area of the triangles, we set the *maxarea* keyword

.. plot:: plot/ex2.py
    :include-source:

If we want to  decrease the area even further

.. plot:: plot/ex3.py
    :include-source:

To do the same with a circle

.. plot:: plot/ex4.py
    :include-source:

.. plot:: plot/ex5.py
    :include-source:

To add a hole in the middle of the circle

.. plot:: plot/ex6.py
    :include-source:

To triangulate with region attributes

.. plot:: plot/ex7.py
    :include-source:

